@@ -11,7 +11,7 @@ class RebootRasp:
     result = False
     user = str(os.popen("echo $USER").read()).strip("\n")
     out_dir = "/home/" + user
-    path = out_dir+'/reboot.json'
+    path = os.path.join(out_dir, 'reboot.json')
 
     def where_json(self):
         return os.path.exists(self.path)
@@ -20,7 +20,7 @@ class RebootRasp:
         if self.where_json():
             return True
         else:
-            with open('reboot.json', 'w') as outfile:
+            with open(self.path, 'w') as outfile:
                 json.dump(self.data, outfile)
             return True
 
@@ -41,7 +41,7 @@ class RebootRasp:
 
     def reboot_now(self):
         if self.create_json():
-            if self.open_url() is False:  # change to true
+            if self.open_url() is True:
                 pass
             else:
                 with open(self.path, 'r') as openfile:
